==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/GetImageUploadUrlForDataPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property entityType Type of entity. Can be Profile or Interaction.
 * @property entityTypeName Name of the entity type.
 * @property hubName The name of the hub.
 * @property relativePath Relative path of the image.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetImageUploadUrlForDataPlainArgs(
    public val entityType: String? = null,
    public val entityTypeName: String? = null,
    public val hubName: String,
    public val relativePath: String? = null,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs =
        com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs.builder()
            .entityType(entityType?.let({ args0 -> args0 }))
            .entityTypeName(entityTypeName?.let({ args0 -> args0 }))
            .hubName(hubName.let({ args0 -> args0 }))
            .relativePath(relativePath?.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetImageUploadUrlForDataPlainArgs].
 */
@PulumiTagMarker
public class GetImageUploadUrlForDataPlainArgsBuilder internal constructor() {
    private var entityType: String? = null

    private var entityTypeName: String? = null

    private var hubName: String? = null

    private var relativePath: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Type of entity. Can be Profile or Interaction.
     */
    @JvmName("orvisecomkdriusw")
    public suspend fun entityType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.entityType = mapped
    }

    /**
     * @param value Name of the entity type.
     */
    @JvmName("mbihjndjyhexhjbd")
    public suspend fun entityTypeName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.entityTypeName = mapped
    }

    /**
     * @param value The name of the hub.
     */
    @JvmName("piylfxkhwshjbgpi")
    public suspend fun hubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hubName = mapped
    }

    /**
     * @param value Relative path of the image.
     */
    @JvmName("ofqhjwlvtagewdfo")
    public suspend fun relativePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.relativePath = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("mfhsjvssajfkmcjj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetImageUploadUrlForDataPlainArgs = GetImageUploadUrlForDataPlainArgs(
        entityType = entityType,
        entityTypeName = entityTypeName,
        hubName = hubName ?: throw PulumiNullFieldException("hubName"),
        relativePath = relativePath,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/GetImageUploadUrlForDataPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property entityType Type of entity. Can be Profile or Interaction.
 * @property entityTypeName Name of the entity type.
 * @property hubName The name of the hub.
 * @property relativePath Relative path of the image.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetImageUploadUrlForDataPlainArgs(
    public val entityType: String? = null,
    public val entityTypeName: String? = null,
    public val hubName: String,
    public val relativePath: String? = null,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs =
        com.pulumi.azurenative.customerinsights.inputs.GetImageUploadUrlForDataPlainArgs.builder()
            .entityType(entityType?.let({ args0 -> args0 }))
            .entityTypeName(entityTypeName?.let({ args0 -> args0 }))
            .hubName(hubName.let({ args0 -> args0 }))
            .relativePath(relativePath?.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetImageUploadUrlForDataPlainArgs].
 */
@PulumiTagMarker
public class GetImageUploadUrlForDataPlainArgsBuilder internal constructor() {
    private var entityType: String? = null

    private var entityTypeName: String? = null

    private var hubName: String? = null

    private var relativePath: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Type of entity. Can be Profile or Interaction.
     */
    @JvmName("dqwbileohlkkpalt")
    public suspend fun entityType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.entityType = mapped
    }

    /**
     * @param value Name of the entity type.
     */
    @JvmName("diryufromgjygoxp")
    public suspend fun entityTypeName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.entityTypeName = mapped
    }

    /**
     * @param value The name of the hub.
     */
    @JvmName("garratxbmtsmqcbj")
    public suspend fun hubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hubName = mapped
    }

    /**
     * @param value Relative path of the image.
     */
    @JvmName("ijgbjqadxkdheplw")
    public suspend fun relativePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.relativePath = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("txehwomligyqmaxb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetImageUploadUrlForDataPlainArgs = GetImageUploadUrlForDataPlainArgs(
        entityType = entityType,
        entityTypeName = entityTypeName,
        hubName = hubName ?: throw PulumiNullFieldException("hubName"),
        relativePath = relativePath,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
